@@ -15,32 +15,36 @@
 #  License along with this library.
 import asyncio
 import traceback
+import concurrent.futures
 
 import octobot_commons.constants as constants
 import octobot_commons.logging as logging_util
 
 
-def run_coroutine_in_asyncio_loop(coroutine, async_loop, log_exceptions=True):
+def run_coroutine_in_asyncio_loop(
+    coroutine, async_loop, log_exceptions=True, timeout=constants.DEFAULT_FUTURE_TIMEOUT
+):
     """
     Run a coroutine in the specified asyncio loop
     :param coroutine: the coroutine to run
     :param async_loop: the asyncio loop
     :param log_exceptions: logs exceptions when True
+    :param timeout: number of seconds to wait for the future before raising a asyncio.TimeoutError
     :return: the execution result
     """
     logger = logging_util.get_logger("asyncio_tools")
     current_task_before_start = asyncio.current_task(async_loop)
     future = asyncio.run_coroutine_threadsafe(coroutine, async_loop)
     try:
-        return future.result(constants.DEFAULT_FUTURE_TIMEOUT)
-    except asyncio.TimeoutError as timeout_error:
+        return future.result(timeout)
+    except (asyncio.TimeoutError, concurrent.futures.TimeoutError) as timeout_error:
         logger.error(
             f"{coroutine} coroutine took too long to execute, cancelling the task. "
             f"(current task before starting this one: {current_task_before_start}, actual current "
             f"task before cancel: {asyncio.current_task(async_loop)})"
         )
         future.cancel()
-        raise timeout_error
+        raise asyncio.TimeoutError from timeout_error
     except Exception as global_exception:
         if log_exceptions:
             logger.exception(
